@@ -30,9 +30,17 @@ DEVICE_IP = Get_Device_IPS()['ext'][0]
 print(DEVICE_IP)
 # >> 192.168.0.3
 
-# Lets get the Public IP Address, if your device is connected to the internet
+# Let's get the Public IP Address, if your device is connected to the internet
 from MkIOT import GetPublicIP
 
 print(GetPublicIP())
 
 # xxx.xxx.xxx.xxx
+
+# Let's get more IP Data
+
+from MkIOT import Get_All_IP_Stat
+
+print(Get_All_IP_Stat())
+
+# {'ext': [{'addr': '192.168.0.3', 'netmask': '255.255.255.0', 'broadcast': '192.168.0.255', 'mac': 'xx:xx:xx:xx:xx:xx'}], 'local': [{'addr': '127.0.0.1', 'netmask': '255.0.0.0', 'broadcast': '127.255.255.255', 'mac': ''}]}
\ No newline at end of file
